#!/usr/bin/perl -w
use strict;

# Converts a .like file into an QccPack cbk code book.
# Needs QccPack from http://qccpack.sourceforge.net/
#
# Usage:
# like2cbk ncodes < file.like > file.cbk
#

use File::Temp qw/tempfile/;

my $ncodes = shift(@ARGV);
my $iterations = 10;

my $overcall = 70; # Log likelihood for overcall error.

#-----------------------------------------------------------------------------
# Create a text file of likelihoods
my ($fh, $fn) = tempfile();

while (<>) {
    my @F = split("\t", $_);
    for (my $i = 4; $i < $#F; $i++) {
	my @G = split(" ", $F[$i]);
	
	# Truncate to integers, as this is all we need for SAM EVcodes anyway
	@G = map { int($_ + 0.5) } @G;
	print $fh "$overcall @G\n";
    }
}
close($fh);

#-----------------------------------------------------------------------------
# Convert it to dat form and use this to generate a code book.
!system("asciitodat -d 5 $fn $fn.dat")
    or die "asciitodat failed: $?";

!system("gla -s $ncodes -I $iterations $fn.dat $fn.cbk")
    or die "gla failed: $?";

system("cat $fn.cbk");

unlink($fn);
unlink("$fn.dat");
unlink("$fn.cbk");
