#!/usr/bin/perl -w

use strict;
use File::Temp qw/tempfile/;

my $cbk = shift(@ARGV);

my $overcall = 70; # Log likelihood for overcall error.

sub process_block {
    # Read 1000 lines of text at a time
    my @lines;
    my $i = 0;
    while (<>) {
	push(@lines, $_);
	$i++;
	last if ($i == 1000);
    }

    return 0 if $i == 0;


    # Create text fiel of likelihoods
    my ($fh, $fn) = tempfile();

    foreach (@lines) {
	my @F = split("\t", $_);

	for (my $i = 4; $i <= $#F; $i++) {
	    my @G = split(" ", $F[$i]);
	
	    @G = map { int($_ + 0.5) } @G;
	    print $fh "$overcall @G\n";
	}
    }
    close($fh) or die;

    # Convert it to binary dat form and from there to a VQ channel
    !system("asciitodat -d 5 $fn $fn.dat")
	or die "asciitodat failed: $?";

    !system("vqencode $fn.dat $cbk $fn.chn")
	or die "vqencode failed: $?";
    unlink("$fn.dat");


    # Now reread the likelihood data, using the VQ file too
    open($fh, "<$fn.chn") or die "$fn.chn: $?";
    <$fh>;
    my $nlines = <$fh>;
    my $ncodes = <$fh>;

    foreach (@lines) {
	chomp($_);
	my @F = split("\t", $_);
	print "$F[0]\t$F[1]\t$F[2]\t$F[3]";
	for (my $i = 4; $i <= $#F; $i++) {
	    my $code = <$fh>;
	    chomp($code);
	    
	    print "\t$F[$i] $code";
	}
	print "\n";
    }
    close($fh);

    unlink("$fn.chn");
    unlink($fn);

    return $i == 1000 ? 1 : 0;
}

my $n = 0;
while (process_block()) {
    print STDERR "Block $n\n";
    $n++
}
